how can I get a devstack version working with docker in my local environment? - Ask OpenStack: Q&A Site for OpenStack Users and Developers
Description: I am trying to install devstack with docker hypervisor. I found out that according to docker documentation on OpenStack wiki you should modify the localrc in order to have VIRT_DRIVER=docker and preinstall /tools/docker/install_docker.sh before running ./stack script. After trying it, I realized that the package /tools/docker is gone from the devstack package: https://github.com/openstack-dev/devstack/commit/7d4c7e09b4882077471c3b2cb097c237c2016f96 So now I am wondering what is the best way to proceed, how can I get a devstack version working with docker in my local environment? Is a manual installation of docker and docker hypervisor the only way to get it working together with devstack?
Keywords: ,Ask, OpenStack,forum,community,cloud,iaas

First time here? Check out the FAQ!

English ▼
Hi there! Please sign in tags users badges help

| ALL UNANSWERED |  | Ask Your Question

9

# how can I get a devstack version working with docker in my local environment?

- devstack
- docker
- hypervisor

asked 2014-04-08 09:24:04 -0600

Ignacio Mulas
111 ●4 ●6 ●9

updated 2015-08-02 19:32:39 -0600

smaffulli
6898 ●36 ●67 ●100 http://maffulli.net/

I am trying to install devstack with docker hypervisor. I found out that according to docker documentation on OpenStack wiki you should modify the localrc in order to have `VIRT_DRIVER=docker` and preinstall `/tools/docker/install_docker.sh` before running ./stack script.

After trying it, I realized that the package `/tools/docker` is gone from the devstack package:

https://github.com/openstack-dev/devstack/commit/7d4c7e09b4882077471c3b2cb097c237c2016f96

So now I am wondering what is the best way to proceed, how can I get a devstack version working with docker in my local environment? Is a manual installation of docker and docker hypervisor the only way to get it working together with devstack?

edit retag flag offensive close merge delete

## Comments

Earlier I tried stable havana: git clone https://github.com/openstack-dev/devs... -b stable/havana

Currently; in dev branch, I am also facing same issue.

SGPJ ( 2014-04-08 11:21:55 -0600 )edit

Yes! I tried the same neither the stable or development branches contains the docker installation script... :(

Ignacio Mulas ( 2014-04-08 14:46:11 -0600 )edit

Vote for the question instead of using the space for an answer to say 'me too'

smaffulli ( 2014-04-09 02:49:07 -0600 )edit
add a comment

## 3 answers

Sort by » oldest newest most voted
1

answered 2014-04-11 13:12:01 -0600

SGPJ
10656 ●59 ●116 ●154 https://in.linkedin.co...

Docker full support will be available in icehouse release. link: http://blog.docker.io/2014/03/docker-... And the best way to use is via heat. The preferred mechanism orchestrating Docker in OpenStack is via Heat, rather than treating Docker as a form of hypervisor in OpenStack Nova.

So we need to wait till April 17th for release.

Thanks.

edit flag offensive delete link more

## Comments

Interesting! But I am a bit confised now. A default nova.conf will be using KVM (for example) and then though Heat you will be able to create container based VMs on the same host? This will mean that heat is overriding the default hypervisor configuration that nova is using? Is this true or I am missing something here?

Ignacio Mulas ( 2014-04-12 04:36:49 -0600 )edit
add a comment
1

answered 2014-09-24 09:32:48 -0600

syed_hussain
11 ●2 ●2

Devstack Docker support is removed in icehouse. The files you are searching are present in havana devstack ./tools/docker/install_docker.sh, Since Openstack supported docker in havana, withdrew docker for icehouse and again planning for juno. Although supported way is with heat http://blog.oddbit.com/2014/08/30/docker-plugin-for-openstack-he/ (http://blog.oddbit.com/2014/08/30/doc...) as declared by docker community. If you are following https://wiki.openstack.org/wiki/Docker , it is outdated one.

I suggest you to either go with havana devstack installation or heat way as I mentioned previously.

edit flag offensive delete link more
add a comment
0

answered 2014-04-11 17:30:45 -0600

cloudssky
491 ●16 ●22 ●39

Shankar, the Heat example shows that a cirros docker container can run inside a ubuntu instance, so whats the revolutionary aspect of this? Today I can also run my CoreOS instances with docker preinstalled, or build my own Ubuntu or CentOS image with docker.

So I guess the right answer to Ignacio's question is: the docker driver is deprecated and heat templates will help to create VM instances with docker containers running in them. But I'm curious how heat could help to run multiple instances with linked containers on different hosts via ambassador containers, but I guess this could be achieved through CoreOS clusters more easily.

edit flag offensive delete link more

## Comments

You mean that you could run a VM based on KVM (for example) on you host and Heat will include the Docker driver in the VM to manage containers inside that VM and not on the host?

Ignacio Mulas ( 2014-04-12 04:44:16 -0600 )edit

Ignacio, unfortunately yes, but I hope, I'm wrong here. My initial expectation was, that you can use the host with docker installed and run containers on the host as if they were VMs and manage them over OpenStack dashboard, assign network, security groups, etc.

cloudssky ( 2014-04-12 04:55:51 -0600 )edit

Exactly! That was my initial though as well... Just have "light" fired container instances running on the host. Anyway, I guess this solution hopefully solves former problems when integrating Docker with Neutron and Cinder. :) Thanks for the hints!

Ignacio Mulas ( 2014-04-12 07:02:44 -0600 )edit
add a comment

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]

# Get to know Ask OpenStack

Resources for moderators

## Question Tools

2 followers

## Stats

Asked: 2014-04-08 09:24:04 -0600

Seen: 2,477 times

Last updated: Aug 02 '15

## Related questions

Volume Error: Error while creating volume in devstack

Problem installation devstak / EC2

devstack instance console hrtimer interrupt took

nova list shows empty table

ceilometer meter-list is working but ceilometer event-list is returning empty event list

VMware hypervisor with no cluster

multiple compute driver on single host (adding Docker)

modifying security group rule

Timed out waiting for nova-conductor

Building Dashboard using horizon error

( 2016-11-08 11:09:56 -0600 )edit
none